import { Button } from "@/components/ui/button";
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { Users, Target, Award, Globe, Heart, Lightbulb } from "lucide-react";
import { Link } from "react-router-dom";
import Header from "@/components/Header";
import Footer from "@/components/Footer";

const About = () => {
  return (
    <div className="min-h-screen bg-background">
      <Header />
      
      {/* Hero Section */}
      <section className="py-20 px-6 bg-gradient-to-br from-blue-50 to-purple-100">
        <div className="container mx-auto max-w-6xl">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            <div>
              <h1 className="text-5xl font-bold mb-6 text-gray-900">
                Empowering Digital Agencies to <span className="text-blue-600">Thrive</span>
              </h1>
              <p className="text-xl text-gray-600 mb-8">
                At Workplaze, we believe that digital professional services companies deserve technology that understands their unique challenges and amplifies their success.
              </p>
              <div className="flex flex-col sm:flex-row gap-4">
                <Link to="/contact-us">
                  <Button size="lg" className="text-lg px-8 py-3">
                    Get in Touch
                  </Button>
                </Link>
                <Link to="/careers">
                  <Button variant="outline" size="lg" className="text-lg px-8 py-3">
                    Join Our Team
                  </Button>
                </Link>
              </div>
            </div>
            <div className="grid grid-cols-2 gap-4">
              <Card className="bg-white/80 backdrop-blur">
                <CardContent className="p-6 text-center">
                  <Users className="w-10 h-10 mx-auto text-blue-600 mb-3" />
                  <div className="text-2xl font-bold">500+</div>
                  <div className="text-sm text-gray-600">Agencies Served</div>
                </CardContent>
              </Card>
              <Card className="bg-white/80 backdrop-blur">
                <CardContent className="p-6 text-center">
                  <Globe className="w-10 h-10 mx-auto text-green-600 mb-3" />
                  <div className="text-2xl font-bold">25+</div>
                  <div className="text-sm text-gray-600">Countries</div>
                </CardContent>
              </Card>
            </div>
          </div>
        </div>
      </section>

      {/* Mission & Vision */}
      <section className="py-16 px-6">
        <div className="container mx-auto max-w-6xl">
          <div className="grid lg:grid-cols-2 gap-12">
            <Card className="border-blue-200 bg-blue-50">
              <CardHeader>
                <Target className="w-12 h-12 text-blue-600 mb-4" />
                <CardTitle className="text-2xl">Our Mission</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="text-lg text-gray-600">
                  To revolutionize how digital professional services companies operate by providing an integrated platform that eliminates inefficiencies, maximizes profitability, and enables sustainable growth.
                </p>
              </CardContent>
            </Card>
            <Card className="border-purple-200 bg-purple-50">
              <CardHeader>
                <Lightbulb className="w-12 h-12 text-purple-600 mb-4" />
                <CardTitle className="text-2xl">Our Vision</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="text-lg text-gray-600">
                  A world where every digital agency has the tools and insights they need to deliver exceptional client value while building profitable, sustainable businesses.
                </p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* Our Story */}
      <section className="py-16 px-6 bg-gray-50">
        <div className="container mx-auto max-w-6xl">
          <h2 className="text-3xl font-bold text-center mb-12">Our Story</h2>
          <div className="max-w-4xl mx-auto">
            <div className="space-y-8">
              <div className="flex items-start space-x-6">
                <div className="w-12 h-12 bg-blue-600 rounded-full flex items-center justify-center text-white font-bold">
                  1
                </div>
                <div>
                  <h3 className="text-xl font-bold mb-2">The Problem We Saw</h3>
                  <p className="text-gray-600">
                    As digital agency veterans, our founders experienced firsthand the frustration of managing multiple disconnected tools, struggling with visibility into project profitability, and watching inefficiencies drain resources.
                  </p>
                </div>
              </div>
              <div className="flex items-start space-x-6">
                <div className="w-12 h-12 bg-green-600 rounded-full flex items-center justify-center text-white font-bold">
                  2
                </div>
                <div>
                  <h3 className="text-xl font-bold mb-2">The Solution We Built</h3>
                  <p className="text-gray-600">
                    We set out to create the platform we wished we'd had - one that truly understood the unique workflows, challenges, and opportunities of digital professional services companies.
                  </p>
                </div>
              </div>
              <div className="flex items-start space-x-6">
                <div className="w-12 h-12 bg-purple-600 rounded-full flex items-center justify-center text-white font-bold">
                  3
                </div>
                <div>
                  <h3 className="text-xl font-bold mb-2">The Impact We're Making</h3>
                  <p className="text-gray-600">
                    Today, hundreds of agencies use Workplaze to increase profitability by an average of 40%, improve team productivity by 25%, and gain the strategic insights they need to grow sustainably.
                  </p>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Values */}
      <section className="py-16 px-6">
        <div className="container mx-auto max-w-6xl">
          <h2 className="text-3xl font-bold text-center mb-12">Our Values</h2>
          <div className="grid md:grid-cols-3 gap-8">
            <Card className="text-center">
              <CardHeader>
                <Heart className="w-12 h-12 mx-auto text-red-600 mb-4" />
                <CardTitle>Customer Success</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="text-gray-600">Your success is our success. We're committed to providing exceptional support and continuously improving our platform based on your feedback.</p>
              </CardContent>
            </Card>
            <Card className="text-center">
              <CardHeader>
                <Lightbulb className="w-12 h-12 mx-auto text-yellow-600 mb-4" />
                <CardTitle>Innovation</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="text-gray-600">We embrace cutting-edge technology like AI and machine learning to provide insights and automation that drive real business value.</p>
              </CardContent>
            </Card>
            <Card className="text-center">
              <CardHeader>
                <Award className="w-12 h-12 mx-auto text-blue-600 mb-4" />
                <CardTitle>Excellence</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="text-gray-600">We set high standards for ourselves and our platform, continuously striving to deliver the best possible experience for our users.</p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="py-16 px-6 bg-blue-600 text-white">
        <div className="container mx-auto max-w-4xl text-center">
          <h2 className="text-3xl font-bold mb-6">Join Our Journey</h2>
          <p className="text-xl mb-8">Whether you're looking to transform your agency or join our mission, we'd love to connect with you.</p>
          <div className="flex flex-col sm:flex-row gap-4 justify-center">
            <Link to="/contact-us">
              <Button size="lg" variant="secondary" className="text-lg px-8 py-3">
                Contact Us
              </Button>
            </Link>
            <Link to="/careers">
              <Button size="lg" variant="outline" className="text-lg px-8 py-3 text-white border-white hover:bg-white hover:text-blue-600">
                View Careers
              </Button>
            </Link>
          </div>
        </div>
      </section>

      <Footer />
    </div>
  );
};

export default About;
